==> baseui-5.5.0.tgz: package/es/datepicker/examples.js <==
var _tests$SIMPLE_EXAMPLE;

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/*
Copyright (c) 2018 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import * as React from 'react';
import { Unstable_Calendar as Datepicker, Unstable_StatefulCalendar as StatefulDatepicker, formatDate } from './index.js';
import { Popover } from '../popover/index.js';
import { Input } from '../input/index.js';
import tests from './examples-list.js';
export var suite = 'Component Test Suite';

var DatepickerWithInput =
/*#__PURE__*/
function (_React$Component) {
  _inherits(DatepickerWithInput, _React$Component);

  function DatepickerWithInput() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, DatepickerWithInput);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(DatepickerWithInput)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {
      isOpen: false,
      value: null,
      formattedValue: ''
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "onChange", function (_ref) {
      var date = _ref.date;

      _this.setState({
        value: date,
        formattedValue: formatDate(date, 'YYYY/MM/dd'),
        isOpen: false
      });
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "open", function () {
      _this.setState({
        isOpen: true
      });
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "close", function () {
      _this.setState({
        isOpen: false
      });
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "handleKeyDown", function (event) {
      if (!_this.state.isOpen && event.keyCode === 40) {
        _this.open();
      }
    });

    return _this;
  }

  _createClass(DatepickerWithInput, [{
    key: "render",
    value: function render() {
      return React.createElement(Popover, {
        isOpen: this.state.isOpen,
        onEsc: this.close,
        content: React.createElement(StatefulDatepicker, {
          onSelect: this.onChange
        })
      }, React.createElement(Input, {
        value: this.state.formattedValue,
        onFocus: this.open,
        onBlur: this.close // Change the on key event types in Input
        // $FlowFixMe
        ,
        onKeyDown: this.handleKeyDown,
        placeholder: "YYYY/MM/DD"
      }));
    }
  }]);

  return DatepickerWithInput;
}(React.Component);

export default (_tests$SIMPLE_EXAMPLE = {}, _defineProperty(_tests$SIMPLE_EXAMPLE, tests.SIMPLE_EXAMPLE, function Story1() {
  return React.createElement(Datepicker, null);
}), _defineProperty(_tests$SIMPLE_EXAMPLE, tests.STATEFUL_EXAMPLE, function Story2() {
  return React.createElement(StatefulDatepicker, null);
}), _defineProperty(_tests$SIMPLE_EXAMPLE, tests.STATEFUL_IN_POPOVER, function Story3() {
  return React.createElement(DatepickerWithInput, null);
}), _defineProperty(_tests$SIMPLE_EXAMPLE, tests.WITH_OVERRIDES, function Story3() {
  var selectOverrides = {
    ControlContainer: {
      style: function style(_ref2) {
        var $theme = _ref2.$theme,
            $isFocused = _ref2.$isFocused,
            $isPseudoFocused = _ref2.$isPseudoFocused;
        return {
          backgroundColor: $isFocused || $isPseudoFocused ? $theme.colors.positive500 : $theme.colors.positive
        };
      }
    },
    OptionContent: {
      style: function style(_ref3) {
        var $theme = _ref3.$theme,
            $isHighlighted = _ref3.$isHighlighted;
        return {
          color: $isHighlighted ? $theme.colors.positive : $theme.colors.foreground
        };
      }
    }
  };
  return React.createElement(StatefulDatepicker, {
    initialState: {
      value: new Date()
    },
    overrides: {
      CalendarHeader: {
        style: function style(_ref4) {
          var $theme = _ref4.$theme;
          return {
            backgroundColor: $theme.colors.positive
          };
        }
      },
      MonthSelect: {
        props: {
          overrides: selectOverrides
        }
      },
      YearSelect: {
        props: {
          overrides: selectOverrides
        }
      },
      Day: {
        style: function style(_ref5) {
          var $theme = _ref5.$theme,
              $selected = _ref5.$selected,
              $isHovered = _ref5.$isHovered,
              $isHighlighted = _ref5.$isHighlighted;
          return {
            backgroundColor: $selected ? $theme.colors.positive : $isHovered || $isHighlighted ? $theme.colors.positive100 : 'transparent'
          };
        }
      }
    }
  });
}), _tests$SIMPLE_EXAMPLE);

==> baseui-5.10.0.tgz: package/es/datepicker/examples.js <==
var _tests$SIMPLE_EXAMPLE;

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/*
Copyright (c) 2018 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import * as React from 'react';
import { Unstable_Calendar as Datepicker, Unstable_StatefulCalendar as StatefulDatepicker, formatDate as _formatDate } from './index.js';
import { Popover, PLACEMENT } from '../popover/index.js';
import { Input } from '../input/index.js';
import tests from './examples-list.js';
export var suite = 'Component Test Suite';

var DatepickerWithInput =
/*#__PURE__*/
function (_React$Component) {
  _inherits(DatepickerWithInput, _React$Component);

  function DatepickerWithInput() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, DatepickerWithInput);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(DatepickerWithInput)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {
      isOpen: false,
      value: _this.props.value || null,
      formattedValue: ''
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "onChange", function (_ref) {
      var date = _ref.date;
      var isOpen = false;

      if (Array.isArray(date) && _this.props.isRange && date.length < 2) {
        isOpen = true;
      }

      _this.setState({
        value: date,
        formattedValue: _this.formatDate(date),
        isOpen: isOpen
      });
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "open", function () {
      _this.setState({
        isOpen: true
      });
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "close", function () {
      _this.setState({
        isOpen: false
      });
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "handleKeyDown", function (event) {
      if (!_this.state.isOpen && event.keyCode === 40) {
        _this.open();
      }
    });

    return _this;
  }

  _createClass(DatepickerWithInput, [{
    key: "formatDate",
    value: function formatDate(date) {
      if (this.props.isRange) {
        // $FlowFixMe
        return date.map(function (day) {
          return _formatDate(day, 'YYYY/MM/dd');
        }).join(' - ');
      }

      return _formatDate(date, 'YYYY/MM/dd');
    }
  }, {
    key: "render",
    value: function render() {
      return React.createElement(Popover, {
        placement: PLACEMENT.bottom,
        isOpen: this.state.isOpen,
        onEsc: this.close,
        content: React.createElement(StatefulDatepicker, {
          initialState: {
            value: this.state.value
          },
          isRange: this.props.isRange,
          onSelect: this.onChange
        })
      }, React.createElement(Input, {
        value: this.state.formattedValue,
        onFocus: this.open // onBlur={this.close}
        // Change the on key event types in Input
        // $FlowFixMe
        ,
        onKeyDown: this.handleKeyDown,
        placeholder: "YYYY/MM/DD"
      }));
    }
  }]);

  return DatepickerWithInput;
}(React.Component);

_defineProperty(DatepickerWithInput, "defaultProps", {
  isRange: false,
  value: null
});

export default (_tests$SIMPLE_EXAMPLE = {}, _defineProperty(_tests$SIMPLE_EXAMPLE, tests.SIMPLE_EXAMPLE, function Story1() {
  return React.createElement(Datepicker, null);
}), _defineProperty(_tests$SIMPLE_EXAMPLE, tests.STATEFUL_EXAMPLE, function Story2() {
  return React.createElement(StatefulDatepicker, null);
}), _defineProperty(_tests$SIMPLE_EXAMPLE, tests.STATEFUL_IN_POPOVER, function Story3() {
  return React.createElement(DatepickerWithInput, null);
}), _defineProperty(_tests$SIMPLE_EXAMPLE, tests.STATEFUL_RANGE_IN_POPOVER, function Story3() {
  return React.createElement(DatepickerWithInput, {
    isRange: true,
    value: []
  });
}), _defineProperty(_tests$SIMPLE_EXAMPLE, tests.STATEFUL_RANGE_QUICK_SELECT, function QuickSelect() {
  return React.createElement(StatefulDatepicker, {
    isRange: true,
    enableQuickSelect: true
  });
}), _defineProperty(_tests$SIMPLE_EXAMPLE, tests.WITH_OVERRIDES, function Story3() {
  var selectOverrides = {
    ControlContainer: {
      style: function style(_ref2) {
        var $theme = _ref2.$theme,
            $isFocused = _ref2.$isFocused,
            $isPseudoFocused = _ref2.$isPseudoFocused;
        return {
          backgroundColor: $isFocused || $isPseudoFocused ? $theme.colors.positive500 : $theme.colors.positive
        };
      }
    },
    OptionContent: {
      style: function style(_ref3) {
        var $theme = _ref3.$theme,
            $isHighlighted = _ref3.$isHighlighted;
        return {
          color: $isHighlighted ? $theme.colors.positive : $theme.colors.foreground
        };
      }
    }
  };
  return React.createElement(StatefulDatepicker, {
    initialState: {
      value: new Date()
    },
    overrides: {
      CalendarHeader: {
        style: function style(_ref4) {
          var $theme = _ref4.$theme;
          return {
            backgroundColor: $theme.colors.positive
          };
        }
      },
      MonthSelect: {
        props: {
          overrides: selectOverrides
        }
      },
      YearSelect: {
        props: {
          overrides: selectOverrides
        }
      },
      Day: {
        style: function style(_ref5) {
          var $theme = _ref5.$theme,
              $selected = _ref5.$selected,
              $isHovered = _ref5.$isHovered,
              $isHighlighted = _ref5.$isHighlighted;
          return {
            backgroundColor: $selected ? $theme.colors.positive : $isHovered || $isHighlighted ? $theme.colors.positive100 : 'transparent'
          };
        }
      }
    }
  });
}), _tests$SIMPLE_EXAMPLE);
